# -*- coding: utf-8 -*-
"""
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Identifier
Package | `__init__.py`

Daniel Bakas Amuchastegui\
May 21, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
"""

from . import bnode, identifier, literal, uriref, variable
from .bnode import *
from .identifier import *
from .literal import *
from .uriref import *
from .variable import *